==> plplot-5.11.1.tar.gz: plplot-5.11.1/doc/doxygen/html/classwxPLDevice.js <==
var classwxPLDevice =
[
    [ "wxPLDevice", "classwxPLDevice.html#af7dc862026548d46a2aa11c2d09f7642", null ],
    [ "~wxPLDevice", "classwxPLDevice.html#a2e742e0f86c46c3ff9b148d36d240ae1", null ],
    [ "BeginPage", "classwxPLDevice.html#a908760e63e954c0b5aadc093c8f9e9ef", null ],
    [ "ClearBackground", "classwxPLDevice.html#adf773b89cce422a8993cff532d1468b5", null ],
    [ "DrawLine", "classwxPLDevice.html#a024a6ab0b2b388e6cf576f19eb570012", null ],
    [ "DrawPolyline", "classwxPLDevice.html#a01db4914fcf1edabcc2e4bb0ccbe4771", null ],
    [ "DrawTextLine", "classwxPLDevice.html#aed5eee301b35cddca3df03aed98831df", null ],
    [ "DrawTextSection", "classwxPLDevice.html#a3467fe2089747cce63432170380719d6", null ],
    [ "EndPage", "classwxPLDevice.html#a250d52287ba56f7ef6ae846622c71cd0", null ],
    [ "FillPolygon", "classwxPLDevice.html#afc705b073a3c6a8225eea0fd2a2ae2a2", null ],
    [ "FixAspectRatio", "classwxPLDevice.html#a4a4d4eab36f783ab13503a8f8ac23a4c", null ],
    [ "Flush", "classwxPLDevice.html#adeba55432fa79202f183ac66cb38be0d", null ],
    [ "GetClipRegion", "classwxPLDevice.html#a2de09de3f0472d8305ece1b8cd2f123c", null ],
    [ "Locate", "classwxPLDevice.html#a633da81974bca97abbe5a8b6c18b6509", null ],
    [ "PreDestructorTidy", "classwxPLDevice.html#a4eaaa2bc3864009dbe0d1a51424d6ae1", null ],
    [ "ProcessString", "classwxPLDevice.html#a3e36024480c793c24484ce348c48c69b", null ],
    [ "SetColor", "classwxPLDevice.html#a89140e210e49e69964fe062386fad2d6", null ],
    [ "SetDC", "classwxPLDevice.html#a30281473d261219cf48f7868800b0584", null ],
    [ "SetSize", "classwxPLDevice.html#a85773a83ecd9f7ff2e2cdd847c537939", null ],
    [ "SetupMemoryMap", "classwxPLDevice.html#acd01ba5f4fdee5373dcabcc44a73e0e0", null ],
    [ "SetWidth", "classwxPLDevice.html#ab812a41d3af92ceab7277d6f90fbbf16", null ],
    [ "TransmitBuffer", "classwxPLDevice.html#a5d478aae15542ab5fa58ef8451de3525", null ],
    [ "m_brush", "classwxPLDevice.html#a4b7480eba456b5ae8b612f8dd46d11ee", null ],
    [ "m_dc", "classwxPLDevice.html#afc1d2a710f600ff2880f37c54ea46e00", null ],
    [ "m_fci", "classwxPLDevice.html#a02d4958fe778365ed994182521ff3388", null ],
    [ "m_fixedAspect", "classwxPLDevice.html#a2306ea3e694a2278f70e8d1f43a6f70d", null ],
    [ "m_fontGrabber", "classwxPLDevice.html#a38e7a85fd5e2e840d5297321b49f067f", null ],
    [ "m_gc", "classwxPLDevice.html#ab7ba43cf0ea08c6a8f00f45317c9c1b9", null ],
    [ "m_height", "classwxPLDevice.html#aeed53943f8c1559f56c8245cdae5ad4c", null ],
    [ "m_lineSpacing", "classwxPLDevice.html#a5f2d941853601f6c276e979d3cfd237a", null ],
    [ "m_localBufferPosition", "classwxPLDevice.html#a8ad3a397168ffe6f2e35c0352fffc2d5", null ],
    [ "m_max_string_length", "classwxPLDevice.html#a1c7e40a21043e7248ebc6efab5a8ea2e", null ],
    [ "m_mfo", "classwxPLDevice.html#a1a6111863fe30260fe178983e6933b94", null ],
    [ "m_mutex", "classwxPLDevice.html#aee5f7baee0b93f262b723613eaeb9d24", null ],
    [ "m_outputMemoryMap", "classwxPLDevice.html#a5733188555ab4b717a512acdd5747e57", null ],
    [ "m_pen", "classwxPLDevice.html#a0079d66c3f5542e7a79624e12ce8e71c", null ],
    [ "m_plplotEdgeLength", "classwxPLDevice.html#ac572a6abcda3170a22d23452c7e1fca2", null ],
    [ "m_posX", "classwxPLDevice.html#abd8e52de2a4fc82ddb896d50a8f3bf3d", null ],
    [ "m_posY", "classwxPLDevice.html#ab80de871c30da895af95491f304274ca", null ],
    [ "m_prevSingleCharString", "classwxPLDevice.html#a8abcf14f0a3204b980b7609ed17c7306", null ],
    [ "m_prevSingleCharStringHeight", "classwxPLDevice.html#a86093029f824890e931904a6aea05319", null ],
    [ "m_prevSingleCharStringWidth", "classwxPLDevice.html#a246c1284577601ee6e2f7e2491bc11bd", null ],
    [ "m_rotation", "classwxPLDevice.html#a8c13a350bdd28ec12e2a4a2053e6b75b", null ],
    [ "m_scale", "classwxPLDevice.html#a50279c0d07a7533de040944191d18e95", null ],
    [ "m_subscriptDepth", "classwxPLDevice.html#a353eebd6fea1cff93cdabf1c5d133d25", null ],
    [ "m_superscriptHeight", "classwxPLDevice.html#a8d126c3a58cdfdcb25aedefc82a8e476", null ],
    [ "m_textDescent", "classwxPLDevice.html#a751358bc32aec65b79859a1927adaaf3", null ],
    [ "m_textHeight", "classwxPLDevice.html#a8f8496ffaa616b077a5d5f5bfb380614", null ],
    [ "m_textLeading", "classwxPLDevice.html#a31255675c031ab0b8e76e549f8b42668", null ],
    [ "m_textWidth", "classwxPLDevice.html#a009d05e9c72977ccf9afb39f71fdcef4", null ],
    [ "m_useDcTextTransform", "classwxPLDevice.html#a096e5f08aa45dd8ea7fc4b71f41b69d1", null ],
    [ "m_width", "classwxPLDevice.html#a39aa02b295b77d9afe40b159405f13d8", null ],
    [ "m_xAspect", "classwxPLDevice.html#ab18473f2c4fa0f288553bebeacc8658d", null ],
    [ "m_xScale", "classwxPLDevice.html#ac4149fda5798c47e92d1b776ed79dda3", null ],
    [ "m_yAspect", "classwxPLDevice.html#ac5877deb7cfa29833eaca2e85ca11e9f", null ],
    [ "m_yScale", "classwxPLDevice.html#a02e7a573c63488a6b0fe4f984a6b9cb7", null ]
];

==> plplot-5.12.0.tar.gz: plplot-5.12.0/doc/doxygen/html/classwxPLDevice.js <==
var classwxPLDevice =
[
    [ "wxPLDevice", "classwxPLDevice.html#af7dc862026548d46a2aa11c2d09f7642", null ],
    [ "~wxPLDevice", "classwxPLDevice.html#a2e742e0f86c46c3ff9b148d36d240ae1", null ],
    [ "BeginPage", "classwxPLDevice.html#a908760e63e954c0b5aadc093c8f9e9ef", null ],
    [ "ClearBackground", "classwxPLDevice.html#adf773b89cce422a8993cff532d1468b5", null ],
    [ "DrawLine", "classwxPLDevice.html#a024a6ab0b2b388e6cf576f19eb570012", null ],
    [ "DrawPolyline", "classwxPLDevice.html#a01db4914fcf1edabcc2e4bb0ccbe4771", null ],
    [ "DrawTextSection", "classwxPLDevice.html#abc5f3cbb3309bb9edf754a38a6449fe6", null ],
    [ "EndPage", "classwxPLDevice.html#a250d52287ba56f7ef6ae846622c71cd0", null ],
    [ "FillPolygon", "classwxPLDevice.html#afc705b073a3c6a8225eea0fd2a2ae2a2", null ],
    [ "FixAspectRatio", "classwxPLDevice.html#a4a4d4eab36f783ab13503a8f8ac23a4c", null ],
    [ "Flush", "classwxPLDevice.html#adeba55432fa79202f183ac66cb38be0d", null ],
    [ "GetClipRegion", "classwxPLDevice.html#a2de09de3f0472d8305ece1b8cd2f123c", null ],
    [ "Locate", "classwxPLDevice.html#a633da81974bca97abbe5a8b6c18b6509", null ],
    [ "PreDestructorTidy", "classwxPLDevice.html#a4eaaa2bc3864009dbe0d1a51424d6ae1", null ],
    [ "SetColor", "classwxPLDevice.html#a89140e210e49e69964fe062386fad2d6", null ],
    [ "SetDC", "classwxPLDevice.html#a30281473d261219cf48f7868800b0584", null ],
    [ "SetSize", "classwxPLDevice.html#a85773a83ecd9f7ff2e2cdd847c537939", null ],
    [ "SetupMemoryMap", "classwxPLDevice.html#acd01ba5f4fdee5373dcabcc44a73e0e0", null ],
    [ "SetWidth", "classwxPLDevice.html#ab812a41d3af92ceab7277d6f90fbbf16", null ],
    [ "TransmitBuffer", "classwxPLDevice.html#a5d478aae15542ab5fa58ef8451de3525", null ],
    [ "m_brush", "classwxPLDevice.html#a4b7480eba456b5ae8b612f8dd46d11ee", null ],
    [ "m_dc", "classwxPLDevice.html#afc1d2a710f600ff2880f37c54ea46e00", null ],
    [ "m_fixedAspect", "classwxPLDevice.html#a2306ea3e694a2278f70e8d1f43a6f70d", null ],
    [ "m_fontGrabber", "classwxPLDevice.html#a38e7a85fd5e2e840d5297321b49f067f", null ],
    [ "m_gc", "classwxPLDevice.html#ab7ba43cf0ea08c6a8f00f45317c9c1b9", null ],
    [ "m_height", "classwxPLDevice.html#aeed53943f8c1559f56c8245cdae5ad4c", null ],
    [ "m_interactiveTextGcdc", "classwxPLDevice.html#ae4bffb81489b74f0b6e7e8d64f5078f8", null ],
    [ "m_interactiveTextImage", "classwxPLDevice.html#a1218ce165c8300691403cee09e5485e0", null ],
    [ "m_lineSpacing", "classwxPLDevice.html#a5f2d941853601f6c276e979d3cfd237a", null ],
    [ "m_localBufferPosition", "classwxPLDevice.html#a8ad3a397168ffe6f2e35c0352fffc2d5", null ],
    [ "m_max_string_length", "classwxPLDevice.html#a1c7e40a21043e7248ebc6efab5a8ea2e", null ],
    [ "m_mfo", "classwxPLDevice.html#a1a6111863fe30260fe178983e6933b94", null ],
    [ "m_mutex", "classwxPLDevice.html#aee5f7baee0b93f262b723613eaeb9d24", null ],
    [ "m_outputMemoryMap", "classwxPLDevice.html#a5733188555ab4b717a512acdd5747e57", null ],
    [ "m_pen", "classwxPLDevice.html#a0079d66c3f5542e7a79624e12ce8e71c", null ],
    [ "m_plplotEdgeLength", "classwxPLDevice.html#ac572a6abcda3170a22d23452c7e1fca2", null ],
    [ "m_prevSingleCharString", "classwxPLDevice.html#a8011085ebdb51ce0cd8883118abddbd8", null ],
    [ "m_prevSingleCharStringDepth", "classwxPLDevice.html#a8b8093342019189974468e0de0613c32", null ],
    [ "m_prevSingleCharStringHeight", "classwxPLDevice.html#a86093029f824890e931904a6aea05319", null ],
    [ "m_prevSingleCharStringWidth", "classwxPLDevice.html#a246c1284577601ee6e2f7e2491bc11bd", null ],
    [ "m_scale", "classwxPLDevice.html#a50279c0d07a7533de040944191d18e95", null ],
    [ "m_useDcTextTransform", "classwxPLDevice.html#a096e5f08aa45dd8ea7fc4b71f41b69d1", null ],
    [ "m_width", "classwxPLDevice.html#a39aa02b295b77d9afe40b159405f13d8", null ],
    [ "m_xAspect", "classwxPLDevice.html#ab18473f2c4fa0f288553bebeacc8658d", null ],
    [ "m_xScale", "classwxPLDevice.html#ac4149fda5798c47e92d1b776ed79dda3", null ],
    [ "m_yAspect", "classwxPLDevice.html#ac5877deb7cfa29833eaca2e85ca11e9f", null ],
    [ "m_yScale", "classwxPLDevice.html#a02e7a573c63488a6b0fe4f984a6b9cb7", null ]
];
